@@ -73,9 +73,9 @@ class Agent(Insight, Channel, Catalog, Dataset):
             self._language = agent.iloc[0]['language']
             self._agent_name = agent.iloc[0]['name']
             if(slug!=''):
-                self.slug=slug
+                self._slug=slug
             else:
-                agent.iloc[0]['slug']
+                self._slug = agent.iloc[0]['slug']
 
         except Exception as ex:
             raise NameError('Agent slug/name/id not exsist or not insert')
@@ -224,7 +224,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
             s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self.slug + '/datasetslug/' + dataset_slug
+            url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self._slug + '/datasetslug/' + dataset_slug
             logging.info("URL {}".format(url))
 
             headers = {"Authorization": "Bearer" + " " + self._token}
@@ -321,7 +321,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         list : filters ([{field: {column: "CONTACTS", alias: null, aggregation: null,…}, operator: "EQ", type: "NUMERIC",…}])
         '''
 
-        dataset_id = self.get_dataset_by_slug(self._agentId, dataset_slug)
+        dataset_id = self.get_dataset_by_slug(self._slug, dataset_slug)
 
         if(dataset_id == None):
 
@@ -330,7 +330,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
             s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            url = self._base_url_askdata + '/smartbot/agents/agentslug/'+self.slug+'/datasetslug/'+dataset_slug
+            url = self._base_url_askdata + '/smartbot/agents/agentslug/'+self._slug+'/datasetslug/'+dataset_slug
             logging.info("URL {}".format(url))
 
             headers = {"Authorization": "Bearer" + " " + self._token}
@@ -593,7 +593,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
     def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
                                   settings: dict = None):
         # Check if dataset exists
-        dataset_id = self.get_dataset_by_slug(self.slug, slug)
+        dataset_id = self.get_dataset_by_slug(self._slug, slug)
 
         dataframe = dataframe.where(pd.notnull(dataframe), None)
         if(dataset_id != None):
